@@ -1,21 +1,7 @@
 /**
- * Copyright 2013 Albert Vaca <albertvaka@gmail.com>
+ * SPDX-FileCopyrightText: 2013 Albert Vaca <albertvaka@gmail.com>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
 #ifndef KDECONNECT_DAEMON_H
@@ -41,6 +27,8 @@ class KDECONNECTCORE_EXPORT Daemon
     Q_CLASSINFO("D-Bus Interface", "org.kde.kdeconnect.daemon")
     Q_PROPERTY(bool isDiscoveringDevices READ isDiscoveringDevices)
     Q_PROPERTY(QStringList pairingRequests READ pairingRequests NOTIFY pairingRequestsChanged)
+   Q_PROPERTY(QStringList customDevices
+              READ customDevices WRITE setCustomDevices NOTIFY customDevicesChanged)
 
 public:
     explicit Daemon(QObject* parent, bool testMode = false);
@@ -55,8 +43,6 @@ public:
     virtual void quit() = 0;
     virtual QNetworkAccessManager* networkAccessManager();
     virtual KJobTrackerInterface* jobTracker() = 0;
-    virtual QString defaultName() const = 0;
-    virtual QString deviceType() const = 0;
 
     Device* getDevice(const QString& deviceId);
 
@@ -64,6 +50,10 @@ public:
 
     QStringList pairingRequests() const;
 
+    // Custom devices
+    QStringList customDevices() const;
+    void setCustomDevices(const QStringList& addresses);
+
     Q_SCRIPTABLE QString selfId() const;
 public Q_SLOTS:
     Q_SCRIPTABLE void acquireDiscoveryMode(const QString& id);
@@ -91,6 +81,7 @@ Q_SIGNALS:
     Q_SCRIPTABLE void deviceListChanged(); //Emitted when any of deviceAdded, deviceRemoved or deviceVisibilityChanged is emitted
     Q_SCRIPTABLE void announcedNameChanged(const QString& announcedName);
     Q_SCRIPTABLE void pairingRequestsChanged();
+    Q_SCRIPTABLE void customDevicesChanged(const QStringList& customDevices);
 
 private Q_SLOTS:
     void onNewDeviceLink(const NetworkPacket& identityPacket, DeviceLink* dl);
